Enum Event
#[non_exhaustive]pub enum Event<'a> {
Begin {
serial: u32,
time: u32,
surface: WlSurface,
fingers: u32,
},
Update {
time: u32,
dx: f64,
dy: f64,
scale: f64,
rotation: f64,
},
End {
serial: u32,
time: u32,
cancelled: i32,
},
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Begin
multi-finger pinch begin
This event is sent when a multi-finger pinch gesture is detected on the device.
Fields
surface: WlSurfaceUpdate
multi-finger pinch motion
This event is sent when a multi-finger pinch gesture changes the position of the logical center, the rotation or the relative scale.
The dx and dy coordinates are relative coordinates in the surface coordinate space of the logical center of the gesture.
The scale factor is an absolute scale compared to the pointer_gesture_pinch.begin event, e.g. a scale of 2 means the fingers are now twice as far apart as on pointer_gesture_pinch.begin.
The rotation is the relative angle in degrees clockwise compared to the previous pointer_gesture_pinch.begin or pointer_gesture_pinch.update event.
Fields
End
multi-finger pinch end
This event is sent when a multi-finger pinch gesture ceases to be valid. This may happen when one or more fingers are lifted or the gesture is cancelled.
When a gesture is cancelled, the client should undo state changes caused by this gesture. What causes a gesture to be cancelled is implementation-dependent.
Implementations